@@ -6,7 +6,7 @@ use 5.014;
 
 use Graphics::Grid::Class;
 
-our $VERSION = '0.0000_02'; # TRIAL VERSION
+our $VERSION = '0.0000_03'; # TRIAL VERSION
 
 use List::AllUtils qw(reduce);
 use Math::Trig qw(:pi :radial deg2rad);
@@ -70,11 +70,6 @@ sub _build__vptree {
 
 sub _build__current_vptree { $_[0]->_vptree }
 
-classmethod singleton() {
-    state $obj = $class->new;
-    return $obj;
-}
-
 
 method current_vptree( $all = true ) {
     return ( $all ? $self->_vptree : $self->_current_vptree );
@@ -303,6 +298,11 @@ method _set_vptree( $vptree = $self->_current_vptree ) {
     $self->_push_gp( grep { defined $_ } map { $_->gp } @$path );
 }
 
+
+method write($filename) {
+    $self->driver->write($filename);
+}
+
 __PACKAGE__->meta->make_immutable;
 
 1;
@@ -319,7 +319,7 @@ Graphics::Grid - An incomplete port of the R "grid" library to Perl
 
 =head1 VERSION
 
-version 0.0000_02
+version 0.0000_03
 
 =head1 SYNOPSIS
 
@@ -332,6 +332,7 @@ version 0.0000_02
             Graphics::Grid::Viewport->new(width => 0.5, height => 0.5));
 
     $grid->rect(gp => Graphics::Grid::GPar->new(col => 'blue'));
+    $grid->write("foo.png");
 
 =head1 DESCRIPTION
 
@@ -373,12 +374,13 @@ standard "plot" system.
 
 It has a "unit" system. a "unit" is basically a numerical value plus a
 unit. The default unit is "npc" (Normalised Parent Coordinates), which
-describes an object's position or dimension relative to those of the parent
-viewport. So when defining a grob, for example a rectangle, usually you do
-not specify its (x, y) position or width or height in absolute values,
-instead you specify its relative position, and width and height in ratio
-to the viewport on which the rectangle is drawn. Beause of this design,
-it's easy to adapt a plot to various types and sizes of graphics devices. 
+describes an object's position or dimension either in relative to those
+of the parent viewport or be absolute. So when defining a grob, for
+example for a rectangle you can specify its (x, y) position or width or
+heightha relative to a viewport, although absolute values are also
+possible and you can combine relative and absolute values. Beause of
+this design, it's easy to adapt a plot to various types and sizes of
+graphics devices. 
 
 =item *
 
@@ -514,6 +516,10 @@ zero
 
 =back
 
+=head2 write($filename)
+
+Write to file.
+
 =head1 TODOS
 
 Including but not limited to,
