@@ -4,7 +4,7 @@ package Graphics::Grid::Dimensional;
 
 use Graphics::Grid::Role;
 
-our $VERSION = '0.0000_02'; # TRIAL VERSION
+our $VERSION = '0.0000_03'; # TRIAL VERSION
 
 use Types::Standard qw(InstanceOf);
 use Graphics::Grid::Types qw(:all);
@@ -14,7 +14,7 @@ use Graphics::Grid::Unit;
 
 has [qw(width height)] => (
     is      => 'ro',
-    isa     => ValueWithUnit,
+    isa     => UnitLike,
     coerce  => 1,
     default => sub { Graphics::Grid::Unit->new(1); },
 );
@@ -33,7 +33,7 @@ Graphics::Grid::Dimensional - Role for supporting width and height in Graphics::
 
 =head1 VERSION
 
-version 0.0000_02
+version 0.0000_03
 
 =head1 DESCRIPTION
 
