@@ -4,7 +4,7 @@ package Graphics::Grid::Driver;
 
 use Graphics::Grid::Role;
 
-our $VERSION = '0.0000_02'; # TRIAL VERSION
+our $VERSION = '0.0000_03'; # TRIAL VERSION
 
 use List::AllUtils qw(reduce);
 use Types::Standard qw(Enum Str InstanceOf Num);
@@ -14,9 +14,9 @@ use Graphics::Grid::Util qw(points_to_cm);
 
 
 has [ 'width', 'height' ] => (
-    is       => 'rw',
-    isa      => Num,
-    default  => 1000,
+    is      => 'rw',
+    isa     => Num,
+    default => 1000,
 );
 
 
@@ -54,6 +54,7 @@ requires 'draw_points';
 requires 'draw_polygon';
 requires 'draw_polyline';
 requires 'draw_rect';
+requires 'draw_segments';
 requires 'draw_text';
 
 sub default_gpar {
@@ -76,26 +77,64 @@ sub default_gpar {
 }
 
 method _transform_width_to_cm(
-    $unit, $idx, $gp,
+    $unitlike, $idx, $gp,
     $vp_width_cm  = $self->_current_vp_width_cm,
     $vp_height_cm = $self->_current_vp_height_cm
   )
 {
-    return $self->_transform_to_cm( $unit, $idx, $gp, $vp_width_cm );
+    return $self->_transform_to_cm( $unitlike, $idx, $gp, $vp_width_cm );
 }
 
 method _transform_height_to_cm(
-    $unit, $idx, $gp,
+    $unitlike, $idx, $gp,
     $vp_width_cm  = $self->_current_vp_width_cm,
     $vp_height_cm = $self->_current_vp_height_cm
   )
 {
-    return $self->_transform_to_cm( $unit, $idx, $gp, $vp_height_cm );
+    return $self->_transform_to_cm( $unitlike, $idx, $gp, $vp_height_cm );
 }
 
-classmethod _transform_to_cm( $unit, $idx, $gp, $length_cm ) {
-    my $value = $unit->value_at($idx);
-    my $unit  = $unit->unit_at($idx);
+classmethod _transform_to_cm( $unitlike, $idx, $gp, $length_cm ) {
+    if ( $unitlike->$_isa('Graphics::Grid::UnitArithmetic') ) {
+        return $class->_transform_unitlike_to_cm( $unitlike, $idx, $gp,
+            $length_cm );
+    }
+    else {    # Graphics::Grid::Unit
+        return $class->_transform_unit_to_cm( $unitlike, $idx, $gp,
+            $length_cm );
+    }
+}
+
+classmethod _transform_unitlike_to_cm( $unitlike, $idx, $gp, $length_cm ) {
+    if ( $unitlike->is_unit ) {
+        return $class->_transform_unit_to_cm( $unitlike->node, $idx, $gp,
+            $length_cm );
+    }
+    elsif ( $unitlike->is_number ) {
+        return $unitlike->node->[ $idx % scalar( @{ $unitlike->node } ) ];
+    }
+    else {    # is_arithmetic
+        my $op = $unitlike->node;
+        my ( $arg0, $arg1 ) = map {
+            $class->_transform_unitlike_to_cm( $unitlike->children->[$_],
+                $idx, $gp, $length_cm )
+        } qw(0 1);
+        if ( $op eq '+' ) {
+            return $arg0 + $arg1;
+        }
+        elsif ( $op eq '-' ) {
+            return $arg0 - $arg1;
+        }
+        else {    # *
+            return $arg0 * $arg1;
+        }
+    }
+}
+
+classmethod _transform_unit_to_cm( $unit, $idx, $gp, $length_cm ) {
+    my $unit_single = $unit->at($idx);
+    my $value       = $unit_single->value->[0];
+    my $unit        = $unit_single->unit->[0];
 
     if ( $unit eq 'npc' ) {
         return $value * $length_cm;
@@ -138,7 +177,7 @@ Graphics::Grid::Driver - Role for Graphics::Grid driver implementations
 
 =head1 VERSION
 
-version 0.0000_02
+version 0.0000_03
 
 =head1 ATTRIBUTES
 
