@@ -4,7 +4,7 @@ package Graphics::Grid::Functions;
 
 use Graphics::Grid::Setup;
 
-our $VERSION = '0.0000_02'; # TRIAL VERSION
+our $VERSION = '0.0000_03'; # TRIAL VERSION
 
 use Module::Load;
 
@@ -28,7 +28,7 @@ our @EXPORT_OK = (
 
 our %EXPORT_TAGS = ( all => \@EXPORT_OK );
 
-my $grid = Graphics::Grid->singleton;
+my $grid = Graphics::Grid->new;    # global object
 
 sub unit {
     return Graphics::Grid::Unit->new(@_);
@@ -47,16 +47,17 @@ sub grid_draw {
 }
 
 sub grid_write {
-    $grid->driver->write(@_);
+    $grid->write(@_);
 }
 
-fun grid_driver(:$driver='Cairo', %rest) {
-    if ($driver->DOES('Graphics::Grid::Driver')) {
+fun grid_driver( :$driver = 'Cairo', %rest ) {
+    if ( $driver->DOES('Graphics::Grid::Driver') ) {
         $grid->driver($driver);
-    } else {
+    }
+    else {
         my $cls = "Graphics::Grid::Driver::$driver";
         load $cls;
-        $grid->driver($cls->new(%rest));
+        $grid->driver( $cls->new(%rest) );
     }
     return $grid->driver;
 }
@@ -104,7 +105,7 @@ Graphics::Grid::Functions - Function interface for Graphics::Grid
 
 =head1 VERSION
 
-version 0.0000_02
+version 0.0000_03
 
 =head1 SYNOPSIS
 
@@ -131,7 +132,9 @@ version 0.0000_02
 
 =head1 DESCRIPTION
 
-This is the function interface for L<Graphics::Grid>.
+This is the function interface for L<Graphics::Grid>. In this package
+it has a global Graphics::Grid object, on which the functions are
+operated.
 
 =head1 FUNCTIONS
 
@@ -238,13 +241,13 @@ Set the device driver. If you don't run this function, the default driver
 will be effective.
 
 If C<$driver> consumes Graphics::Grid::Driver, C<$driver> is assigned to
-the grid singleton, and C<%rest> is ignored.
+the global Graphics::Grid object, and C<%rest> is ignored.
 
     grid_driver(driver => Graphics::Grid::Driver::Cairo->new(...));
 
-If C<$driver> is a string, a C<Graphics::Grid::Driver::$driver> object is
+If C<$driver> is a string, a Graphics::Grid::Driver::$driver object is
 created with C<%rest> as construction parameters, and is assigned to the
-grid singleton.
+global Graphics::Grid object.
 
     grid_driver(driver => 'Cairo', width => 800, height => 600);
 
