@@ -4,7 +4,7 @@ package Graphics::Grid::Grob::Circle;
 
 use Graphics::Grid::Class;
 
-our $VERSION = '0.0000_02'; # TRIAL VERSION
+our $VERSION = '0.0000_03'; # TRIAL VERSION
 
 use List::AllUtils qw(max);
 
@@ -14,7 +14,7 @@ use Graphics::Grid::Types qw(:all);
 
 has r => (
     is      => 'ro',
-    isa     => ValueWithUnit,
+    isa     => UnitLike,
     coerce  => 1,
     default => sub { Graphics::Grid::Unit->new(0.5) }
 );
@@ -48,7 +48,7 @@ Graphics::Grid::Grob::Circle - Circle grob
 
 =head1 VERSION
 
-version 0.0000_02
+version 0.0000_03
 
 =head1 SYNOPSIS
 
