@@ -5,7 +5,7 @@ package Graphics::Grid::Grob::Points;
 use Graphics::Grid::Class;
 use MooseX::HasDefaults::RO;
 
-our $VERSION = '0.0000_02'; # TRIAL VERSION
+our $VERSION = '0.0000_03'; # TRIAL VERSION
 
 use Graphics::Grid::Unit;
 use Graphics::Grid::Types qw(:all);
@@ -16,7 +16,7 @@ has pch => ( isa => PlottingCharacter, default => 1 );
 
 
 has size => (
-    isa     => ValueWithUnit,
+    isa     => Unit,
     coerce  => 1,
     default => sub { Graphics::Grid::Unit->new( 1, "char" ) },
 );
@@ -78,7 +78,7 @@ Graphics::Grid::Grob::Points - Points grob
 
 =head1 VERSION
 
-version 0.0000_02
+version 0.0000_03
 
 =head1 SYNOPSIS
 
