@@ -5,7 +5,7 @@ package Graphics::Grid::Grob::Polyline;
 use Graphics::Grid::Class;
 use MooseX::HasDefaults::RO;
 
-our $VERSION = '0.0000_02'; # TRIAL VERSION
+our $VERSION = '0.0000_03'; # TRIAL VERSION
 
 use List::AllUtils qw(uniq);
 use Types::Standard qw(ArrayRef Int);
@@ -19,13 +19,20 @@ has id => ( isa => ArrayRef [Int] );
 # TODO
 # has arrow => ( isa => ArrayRef[$Arrow] );
 
-has _points_by_idx => (
+has _indexes_by_id => (
     is       => 'ro',
     lazy     => 1,
-    builder  => '_build__points_by_idx',
+    builder  => '_build__indexes_by_id',
     init_arg => undef
 );
 
+has _ids => (
+    is       => 'ro',
+    lazy     => 1,
+    builder  => '_build__ids',
+    init_arg => undef,
+);
+
 with qw(
   Graphics::Grid::Grob
   Graphics::Grid::Positional
@@ -38,46 +45,48 @@ has [qw(+x +y)] => (
 
 
 method _build_elems() {
-    unless ( $self->has_id ) {
-        return 1;
-    }
-    return scalar( uniq( @{ $self->id } ) );
+    return scalar( @{ $self->_ids } );
 }
 
-method _build__points_by_idx() {
+method _build__ids() {
     if ( !$self->has_id ) {
-        return { 0 => { x => $self->x, y => $self->y } };
+        return [0];
     }
     else {
-        my %points_by_id;
-        for my $i ( 0 .. $self->x->elems - 1 ) {
-            my $id = $self->id->[$i];
-            $points_by_id{$id} //= [];
-            push @{ $points_by_id{$id} },
-              [ $self->x->at($i), $self->y->at($i) ];
-        }
-
-        my @ids_sorted = sort keys %points_by_id;
-        my %points_by_idx =
-          map {
-            my $id = $_;
-            my $points  = $points_by_id{ $ids_sorted[$id] };
-            my @x       = map { $_->[0] } @$points;
-            my @x_value = map { $_->value_at(0); } @x;
-            my @x_unit  = map { $_->unit_at(0); } @x;
-            my @y       = map { $_->[1] } @$points;
-            my @y_value = map { $_->value_at(0); } @y;
-            my @y_unit  = map { $_->unit_at(0); } @y;
-
-            $id => {
-                x => Graphics::Grid::Unit->new( \@x_value, \@x_unit ),
-                y => Graphics::Grid::Unit->new( \@y_value, \@y_unit ),
-            };
-          } ( 0 .. $#ids_sorted );
-        return \%points_by_idx;
+        my @ids = uniq( @{ $self->id } );
+        return \@ids;
     }
 }
 
+method _build__indexes_by_id() {
+    if ( !$self->has_id ) {
+        return { 0 => [ 0 .. $self->x->elems - 1 ] };
+    }
+    else {
+        my %indexes_by_id = map { $_ => [] } @{ $self->id };
+        for my $idx ( 0 .. $#{ $self->id } ) {
+            my $id = $self->id->[$idx];
+            push @{ $indexes_by_id{$id} }, $idx;
+        }
+        return \%indexes_by_id;
+    }
+}
+
+
+method indexes_by_id($id) {
+    return $self->_indexes_by_id->{$id};
+}
+
+
+method unique_ids() {
+    return $self->_ids;
+}
+
+method get_idx_by_id($id) {
+    my @indexes = map { $_ == $id } @{ $self->id };
+    return \@indexes;
+}
+
 method _has_param($name) {
     my $val = $self->$name;
     return ( defined $val and @{$val} > 0 );
@@ -99,11 +108,6 @@ method validate() {
     }
 }
 
-method get_points($idx) {
-    my $points_by_idx = $self->_points_by_idx;
-    return $points_by_idx->{$idx};
-}
-
 method draw($driver) {
     $driver->draw_polyline($self);
 }
@@ -124,7 +128,7 @@ Graphics::Grid::Grob::Polyline - Polyline grob
 
 =head1 VERSION
 
-version 0.0000_02
+version 0.0000_03
 
 =head1 SYNOPSIS
 
@@ -209,6 +213,18 @@ attribute.
 For this module C<elems> returns the number of lines (number of unique
 C<id>) of a object.
 
+=head1 METHODS
+
+=head2 indexes_by_id($id)
+
+Get unit indexes of attributes C<x>, C<y>, C<id>, for a given id.
+
+Returns an array ref.
+
+=head2 unique_ids
+
+Return an array ref of unique ids.
+
 =head1 CONSTRUCTOR
 
 =head1 SEE ALSO
