@@ -4,7 +4,7 @@ package Graphics::Grid::Positional;
 
 use Graphics::Grid::Role;
 
-our $VERSION = '0.0000_02'; # TRIAL VERSION
+our $VERSION = '0.0000_03'; # TRIAL VERSION
 
 use Types::Standard qw(InstanceOf);
 use Graphics::Grid::Types qw(:all);
@@ -14,7 +14,7 @@ use Graphics::Grid::Unit;
 
 has [qw(x y)] => (
     is      => 'ro',
-    isa     => ValueWithUnit,
+    isa     => UnitLike,
     coerce  => 1,
     default => sub { Graphics::Grid::Unit->new(0.5) },
 );
@@ -33,7 +33,7 @@ Graphics::Grid::Positional - Role for supporting (x, y) position in Graphics::Gr
 
 =head1 VERSION
 
-version 0.0000_02
+version 0.0000_03
 
 =head1 DESCRIPTION
 
